function [ dy ] = HHModel(t, y, I_in)
% HHModel(t, y, I_in) compute the ifferential equations the Hodgkin-Huxley model.
%   Function returns the time differential of variables V, m, n and h.
%
%
%   Example:
%
%   T = 150;
%   I_current = 7;
%   y_ini = [0  0.05  0.3  0.6];
%
%   [t, y] = ode45(@(t, y) HHModel(t, y, I_current), [0  T], y_ini);
% 
%   V = y(:,1);
%   m = y(:,2);
%   n = y(:,3);
%   h = y(:,4);
%   plot(t, V)


% Constrent Parameters
C  = 1;    % (1 muF/cm^2)
gL = 0.3;  % ( mS/cm^2)
gNa= 120;
gK = 36;

VL = 10.613;
VNa= 115;
VK = -12;

% Set the variables for previous time step
V = y(1);
m = y(2);
n = y(3);
h = y(4);

% Differential equations of HH models
am = (-0.1*V + 2.5)/(exp(-0.1*V +2.5)-1);       bm = 4.*exp(-V/18);
an = (-0.01*V + 0.1)/(exp(-0.1*V + 1)-1);       bn = 0.125.*exp(-V/80);
ah = (0.07).*exp(-V/20);                        bh = 1./(exp(-V/10 + 3)+1);

dV = (- gL.*(V - VL) - gNa*m.^3*h.*(V - VNa) - gK*n.^4*(V - VK) + I_in)./C;
dm = am.*(1-m) - bm.*m;
dn = an.*(1-n) - bn.*n;
dh = ah.*(1-h) - bh.*h;

dy = [dV dm dn dh]';

end

